function res = hvap_0()

    % Read in reference enthalpy of vaporization data and the corresonding index
    Training_prop = xlsread('Pure_Component.xlsx','Enthalpy of Vaporization_0','D3:D97');
    Training_index = xlsread('Pure_Component.xlsx','Enthalpy of Vaporization_0','A3:A97');
    
    Indices = Training_index ~= 124;
    
    % Filter out acetic acid
    Training_prop = Training_prop(Indices);
    Training_index = Training_index(Indices);
    
    % Next, read in our matrix of MOSCED parameters.
    % v, lambda, tau, q, alpha, and beta
    MOS= xlsread('Pure_Component.xlsx','CAS','E2:J132');
    % Filter the relevant MOCSCED parameters
    MOS2 = MOS(Training_index,:);
    
    % Split-up
    V = MOS2(:,1);
    Lambda = MOS2(:,2);
    Tau = MOS2(:,3);
    Alpha = MOS2(:,5);
    Beta = MOS2(:,6);
    
    % Our multilinear regression will be of the from:
    % c0 + v*(c1*lambda^2 + c2*tau^2 + c3*alpha*beta)
    % or equivalently
    % c0*1 + c1*v*lambda^2 + c2*v*tau^2 + c3*v*alpha*beta
    %
    % The terms v*lambda^2, v*tau^2, and v*alpha*beta will have
    % units of energy, here J/mol. The relevant conversion factor will be
    % included in the constants.
    % 
    % Next, let's set-up a matrix to hold our descriptors:
    %  1, v*lambda^2, v*tau^2, v*alpha*beta
    Training_matrix = ones(length(Training_prop),4);
    
    r = 8.314462618;
    t_K = 0+273.15;
    
    Vrt = V./(r*t_K);
    %Vrt = 1;
    
    % Make the enthalpy of vaporization dimensionless
    Training_prop = 1000.*Training_prop./(r*t_K);
    
    % Computing descriptors
    %Training_matrix(:,1) = Vrt;
    %
    Training_matrix(:,2) = Vrt.*Lambda.^(2);
    Training_matrix(:,3) = Vrt.*Tau.^(2);
    Training_matrix(:,4) = Vrt.*Alpha.*Beta;
    %
    Training_matrix(:,5) = Vrt.*Alpha.^(2);
    Training_matrix(:,6) = Vrt.*Beta.^(2);
    
    % Fitting!
    [C_train,rsq_train,rms_train,Pred_train,stanDev,pError] = multi_fitter(Training_matrix,Training_prop);
    C_train
    rsq_train
    rms_train
    stanDev
    pError
    length(Training_prop)
    
    %parity plot
    figure(1)
    hold on
    plot(Training_prop,Pred_train,'ko')
    plot([5,40],[5,40],'-k')
    xlim([5,40])
    ylim([5,40])
    xlabel('\Delta H^{vap}/(RT) ref')
    ylabel('\Delta H^{vap}/(RT) calc')
    
    %residual plot
    figure(2)
    hold on
    residuals = Training_prop-Pred_train;
    plot(residuals, 'ko');
    plot([0,100],[0,0], '-k')
    ylabel('Residual')
    title('Residual Plot')
    
    res = [Training_prop, Pred_train];
end

function [Coeff,rsq,rms_error,Pred,stanDev,pError] = multi_fitter(P_matrix,Ref)

    % First, determine coefficeints of fit
    Coeff = P_matrix\Ref;
    
    % Next, we want R^2. 
    Pred = P_matrix*Coeff;
    rsq = corr(Ref,Pred)^(2);
    
    
    %Standard Deviation Calculation
    diff=Ref-Pred;
    stanDev=std(abs(diff));
    
    %Percent Error Calculation
    pError = mean(abs((diff)./Ref)).*100;
    
    % And finally the RMS error
    Sq_diff = (Ref-Pred).^(2);
    rms_error = sqrt(mean(Sq_diff));
end

